ams.system
==========

.. automodule:: ams.system

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
      :toctree:
   
      disable_method
      disable_methods
      example
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :toctree:
   
      System
   
   

   
   
   



